@@ -14,7 +14,7 @@ class ChatMessage(BaseModel):  # type: ignore
 ChatMessages = List[ChatMessage]
 
 
-async def llm_acall(model_name: str, messages: ChatMessages) -> str:
+async def llm_acall(model_name: str, messages: ChatMessages, **kwargs: Any) -> str:
     key = os.getenv("OPENROUTER_API_KEY", "")
     assert key, "Please set OPENROUTER_API_KEY in the environment variables"
     base_url = os.getenv("BASE_URL", "https://openrouter.ai/api/v1")
@@ -25,7 +25,7 @@ async def llm_acall(model_name: str, messages: ChatMessages) -> str:
             await client.chat.completions.create(
                 model=model_name,
                 messages=messages,
-                temperature=0.0,
+                **kwargs,
             )
         )
         .choices[0]
