@@ -12,7 +12,7 @@ from .latex import (
 )
 from .web_search import web_search, tavily_web_search, exa_web_search, brave_web_search
 from .visit_webpage import visit_webpage
-from .bitflip import extract_bitflip_info, generate_research_proposal, score_research_proposals
+from .bitflip import extract_bitflip_info, generate_research_proposals, score_research_proposals
 from .review import review_pdf_paper, download_pdf_paper
 
 __all__ = [
@@ -33,7 +33,7 @@ __all__ = [
     "brave_web_search",
     "visit_webpage",
     "extract_bitflip_info",
-    "generate_research_proposal",
+    "generate_research_proposals",
     "score_research_proposals",
     "review_pdf_paper",
     "download_pdf_paper",
